==========
User Guide
==========

.. Note:: This section is under construction.


To use Pulsarbat in a project:

.. code-block:: python

    import pulsarbat as pb


.. toctree::
   :caption: Tutorials
   :maxdepth: 1

   getting_started
   signals
   readers
